#!/usr/bin/python3

import os

# doc.py 2020-08-22 ver 1.0-0
# this python3 script loads a text file from disk and writes an html file
# the text file must have at least two blank lines at the end
# it parses the text file (outline style) according to line indentation
# it recognizes indentations of (spaces, tabs not supported) 4, 8, 12, 16
# html tags, colors, fonts and css are configured at the end of this script
# a blank line in the text file will create a new DIV
# lines will have <BR> appended to the end when paragraph='' or paragraph=0
# long lines will be wrapped within the <DIV> width for that indentation
# lines that are indented 12 spaces will be tagged <em></em>
# lines that have a ")" in the first 3 characters will be tagged <strong></strong>
# lines that have an "##" anywhere in them will be tagged <pre></pre>
# lines that are indented 16 spaces will be centered, paragraph style
# One word lines in indented 16 paragraphs are centered in <p></p> tags,
# titling the paragraph or breaking up the paragraph into titled sections

# the loadName to load text from and the writeName to write html to
loadName="/home/gary/projects/cronemail/doc/README"
writeName="/home/gary/projects/cronemail/doc/bogoTrainer.html"
paragraph=''

def addTags(thisLine,indent):

    # this is called for all lines
    # these tags will be added to lines that
    # match the criteria specified
    thisLine=thisLine.lstrip()

    if ")" in thisLine[:3]:
        # for numbered lines 1) .... 99)
        # make the first line strong
        thisLine="<strong>"+thisLine+"</strong>"
    elif "##" in thisLine:
        # for lines that benefit from <pre>
        # where text needs to be lined up just right
        # all lines have a <BR> at the end
        # pre doesn't need one, so it's removed here
        thisLine=thisLine.replace("<BR>","")
        thisLine="<pre>"+thisLine+"</pre>"

    # next indent specific tags can be
    # added to each line
    if indent==16:
        thisLine=thisLine.replace('<BR>',' ')
        wordCount=len(thisLine.split())
        if wordCount==1:
            # if there is a single word on a line use it
            # as a title for the paragraph that follows
            thisLine='<p>'+thisLine+'</p>'
    elif indent==12:
        # <em> shouldn't be inside a <pre> tag
        if "##" not in thisLine:
            thisLine="<em>"+thisLine+"</em>"
    elif indent==8:
        thisLine=thisLine
    elif indent==4:
        thisLine=thisLine

    return thisLine

# load the file
d=open(loadName,"r")
dlines=d.readlines()
d.close()

doc=""
linex=[]
content="0"
preIndent=0

# convert the text to html
for x in dlines:
    xIndent=len(x) - len(x.lstrip(' '))
    if not paragraph:
        x=x+"<BR>"

    if xIndent==16:
        # this line starts with 16 spaces
        # this content is centered
        content="content"+str(xIndent)
        x=addTags(x,xIndent)
        linex.append(x)
        preIndent=12

    elif xIndent==12:
        # this line starts with 12 spaces
        content="content"+str(xIndent)
        x=addTags(x,xIndent)
        linex.append(x)
        preIndent=8

    elif xIndent==8:
        # this line starts with 8 spaces
        content="content"+str(xIndent)
        x=addTags(x,xIndent)
        linex.append(x)
        preIndent=4

    elif xIndent==4:
        # this line starts with 4 spaces
        content="content"+str(xIndent)
        x=addTags(x,xIndent)
        linex.append(x)
        preIndent=0

    elif xIndent==0 and  x[0] != "\n":
        # the line must start with a character/number at position 0 on the line
        content="content"+str(0)
        x=addTags(x,0)
        linex.append(x)
        preIndent=0

    elif x[0] == "\n":
        # the line must be empty
        if preIndent==0:
            linex.insert(0,'<DIV CLASS="'+content+'">')
            linex.append('</DIV>')
        elif preIndent==4:
            linex.insert(0,'<DIV CLASS="content'+str(preIndent)+'">')
            linex.insert(1,'<DIV CLASS="'+content+'">')
            linex.append('</DIV>')
            linex.append('</DIV>')
        elif preIndent==8:
            linex.insert(0,'<DIV CLASS="content'+str(preIndent-4)+'">')
            linex.insert(1,'<DIV CLASS="content'+str(preIndent)+'">')
            linex.insert(2,'<DIV CLASS="'+content+'">')
            linex.append('</DIV>')
            linex.append('</DIV>')
            linex.append('</DIV>')
        elif preIndent==12:
            linex.insert(0,'<DIV CLASS="content'+str(preIndent-8)+'">')
            linex.insert(1,'<DIV CLASS="content'+str(preIndent-4)+'">')
            linex.insert(2,'<DIV CLASS="content'+str(preIndent)+'">')
            linex.insert(3,'<DIV CLASS="'+content+'">')
            linex.append('</DIV>')
            linex.append('</DIV>')
            linex.append('</DIV>')
            linex.append('</DIV>')

        doc=doc+"".join(linex)
        linex=[]

# some css variables
bodycolor="#42E6EC"

bg0="#EFF6F9"
color0="#0019BB"
f0="font: 32px sans"

bg4="#6BEAEE"
color4="#000000"
f4="font:18px sans"

bg8="#BDF6F8"
color8="#000000"
f8="font:16px sans"

bg12="#DBFFFD"
color12="#000000"
f12="font:14px sans"

bg16="#42E6EC"
color16="#000000"
f16="font:16px sans"

style="\n"\
" body {background-color:"+bodycolor+"}\n"\
".content0 {width:980px;padding:5px 0px 5px 10px;"+f0+";background-color:"+bg0+";color:"+color0+";}\n"\
".content4 {position:relative;top:0px;bottom:0px;left:50px;"+f4+";"\
" width: 920px;padding: 10px 10px 10px 10px;background-color:"+bg4+";color:"+color4+";}\n"\
".content8 {position:relative;top:0px;bottom:0px;left:50px;"+f8+";"\
" width: 860px;padding: 10px 10px 10px 10px;background-color:"+bg8+";color:"+color8+";}\n"\
".content12 {position:relative;top:0px;bottom:0px;left:50px;"+f12+";"\
" width: 800px;padding: 10px 10px 10px 10px;background-color:"+bg12+";color:"+color12+";}\n"\
".content16 {position:relative;top:0px;bottom:0px;left:50px;"+f16+";"\
" width: 570px;text-align:center;padding: 10px;background-color:"+bg16+";color:"+color16+";}\n"\

# title is the first word in the first line
# ~ title="<TITLE>"+dlines[0].split()[0]+"</TITLE>"
title="<TITLE>"+dlines[0]+"</TITLE>"

# assemble the html
htmlBody=["<BODY>\n",doc,"\n</BODY>\n"]
htmlStyle=["<STYLE>\n",style,"</STYLE>\n"]
htmlHead=["<HEAD>\n",title+"\n","".join(htmlStyle),"</HEAD>\n\n"]
htmlMain=["<HTML>\n","".join(htmlHead),"".join(htmlBody),"\n</HTML>\n"]
htmlDoc=" ".join(htmlMain)

d=open(writeName,"w")
d.write(htmlDoc)
d.close()

# uncomment this line to print the htmldoc to the screen
# ~ print (doc)
